from enum import Enum
from typing import Iterable, Tuple


class Units(str, Enum):
    seconds = 's'
    milliseconds = 'ms'
    number = 'none'
    megahertz = 'rotmhz'
    joule = 'joule'
    watt = 'watt'
    gigabyte = 'decgbytes'
    mbytes_per_second = 'MBs'
    flop_per_byte = 'Flop/Byte'
    mflop_sec = 'mflops'
    percent = 'percentunit'


class AxisLabel(str, Enum):
    mlups = 'MLUPS per process'
    runtime = 'Runtime'
    tts = 'Time to Solution'
    dp_perf = 'Double Precision Performance'
    oi = 'Operational Intensity'
    memory_read_bw = 'Memory Read Bandwidth'
    memory_write_bw = 'Memory Write Bandwidth'
    memory_bw = 'Memory Bandwidth'
    memory_read_volume = 'Memory Read Volume'
    memory_write_volume = 'Memory Write Volume'
    memory_volume = 'Memory Volume'
    power = 'Power'
    energy = 'Energy'
    clock_speed = 'Clock Speed'


def build_alias_entry(descr, var_name) -> str:
    return f"{descr}: $tag_{var_name}"


def build_alias(alias_entries: Iterable[Tuple[str, str]]) -> str:
    return ", ".join(
        build_alias_entry(descr, var_name)
        for descr, var_name in alias_entries
    )
