from grafanalib.core import (Dashboard, Repeat, RowPanel, Templating, Time,
                             TimeSeries)

from dashboards.variables import get_dashboard_variable_query
from dashboards.dashboard_base import (get_commit_annotation,
                                       get_influx_target)
from dashboards.dashboard_list import dashboard_uniformGridGPU
from dashboards.dashboard_fe2ti import dashboard_fe2ti
from dashboards.dashboard_pystencils import dashboard_pystencils_cpu, dashboard_pystencils_gpu
from dashboards.dashboard_walberla import dashboard_uniformgridgpu, dashboard_uniformgridcpu
from dashboards.influx_queries import Query, show_tag_values

dataSource = 'InfluxDB-1'
measurment_name = 'UniformGridGPU'
q1 = Query(
    select_='mlupsPerProcess',
    from_=measurment_name,
    where_='"collisionSetup" =~ /^${collisionSetup:regex}$/ AND "host" =~ /^${host:regex}$/ AND "cellsPerBlock_0" =~ /^${cellsPerBlock_0:regex}$/',
    group_by=[
            "blocks_0",
            "blocks_1",
            "blocks_2",
            "cellsPerBlock_0",
            "cellsPerBlock_1",
            "cellsPerBlock_2",
            "gpuBlockSize_0",
            "gpuBlockSize_1",
            "gpuBlockSize_2",
            "collisionSetup",
            "stencil",
            "streamingPattern"
    ]
)

host_var = get_dashboard_variable_query("host",
                                        show_tag_values(measurment_name, "host"),
                                        dataSource)
collisionsetup_var = get_dashboard_variable_query("collisionSetup",
                                                  show_tag_values(measurment_name, "collisionSetup"),
                                                  dataSource)

other_filter = 'cellsPerBlock_0'
cellsPerBlock_var = get_dashboard_variable_query(other_filter,
                                                 show_tag_values(measurment_name, other_filter),
                                                 dataSource)

dashboard = Dashboard(
    title="Uniform Grid GPU",
    description="Benchmark dashboard for the Uniform Grid GPU Benchmark from walberla",
    tags=[
        'GPU',
        'benchmark',
        'walberla',
        'Uniform Grid'
    ],
    timezone="browser",
    rows=[
        RowPanel(
            title="collisionSetup: $collisionSetup",
            collapsed=True,
            panels=[
                TimeSeries(
                    title='host: $host',
                    dataSource=dataSource,
                    targets=[
                        get_influx_target(str(q1))
                    ],
                    repeat=Repeat('h', host_var.name),
                    unit='none',
                    axisLabel='MLUPS per process',
                    pointSize=9,
                ),
            ],
            repeat=Repeat('v', collisionsetup_var.name),
        ),
    ],
    templating=Templating([host_var, collisionsetup_var, cellsPerBlock_var]),
    time=Time('now-30d', 'now'),
    annotations=get_commit_annotation(dataSource, "red", "commits", measurment_name),
).auto_panel_ids()


def test_build_dashboard():
    assert dashboard_uniformGridGPU() == dashboard


def test_dashboard_fe2ti():
    dashboard_fe2ti()


def test_dashboard_pystencils_cpu():
    dashboard_pystencils_cpu()
    dashboard_pystencils_gpu()


def test_dashboard_walberla():
    dashboard_uniformgridcpu()
    dashboard_uniformgridgpu()
