# Test case using pytest
import pytest
from dashboards.upload import load_config_from_env
from unittest.mock import patch
import os

def test_load_config_from_env():
    # Case 1: Test if function raises exception for missing GRAFANA_API_KEY
    with pytest.raises(ValueError) as e:
        load_config_from_env(env_path=".env")
    assert str(e.value) == "GRAFANA_API_KEY is None or not defined in the .env file"

    # Case 2: Test if function raises exception for missing GRAFANA_SERVER
    with patch.dict(os.environ, {"GRAFANA_API_KEY": "api_key"}):
        with pytest.raises(ValueError) as e:
            load_config_from_env(env_path=".env")
        assert str(e.value) == "GRAFANA_SERVER is None or not defined in the .env file"

    # Case 3: Test if function returns expected values when both variables are defined
    with patch.dict(os.environ, {"GRAFANA_API_KEY": "api_key", "GRAFANA_SERVER": "server_url"}):
        result = load_config_from_env(env_path=".env")
        assert result == ("server_url", "api_key")